==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/azure/v1/OSDiskFluent.java <==
package io.fabric8.openshift.api.model.hive.azure.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OSDiskFluent<A extends OSDiskFluent<A>> extends BaseFluent<A>{
  public OSDiskFluent() {
  }
  
  public OSDiskFluent(OSDisk instance) {
    this.copyInstance(instance);
  }
  private DiskEncryptionSetBuilder diskEncryptionSet;
  private Integer diskSizeGB;
  private String diskType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OSDisk instance) {
    instance = (instance != null ? instance : new OSDisk());
    if (instance != null) {
          this.withDiskEncryptionSet(instance.getDiskEncryptionSet());
          this.withDiskSizeGB(instance.getDiskSizeGB());
          this.withDiskType(instance.getDiskType());
          this.withDiskEncryptionSet(instance.getDiskEncryptionSet());
          this.withDiskSizeGB(instance.getDiskSizeGB());
          this.withDiskType(instance.getDiskType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public DiskEncryptionSet buildDiskEncryptionSet() {
    return this.diskEncryptionSet != null ? this.diskEncryptionSet.build() : null;
  }
  
  public A withDiskEncryptionSet(DiskEncryptionSet diskEncryptionSet) {
    this._visitables.remove(this.diskEncryptionSet);
    if (diskEncryptionSet != null) {
        this.diskEncryptionSet = new DiskEncryptionSetBuilder(diskEncryptionSet);
        this._visitables.get("diskEncryptionSet").add(this.diskEncryptionSet);
    } else {
        this.diskEncryptionSet = null;
        this._visitables.get("diskEncryptionSet").remove(this.diskEncryptionSet);
    }
    return (A) this;
  }
  
  public boolean hasDiskEncryptionSet() {
    return this.diskEncryptionSet != null;
  }
  
  public A withNewDiskEncryptionSet(String name,String resourceGroup,String subscriptionId) {
    return (A)withDiskEncryptionSet(new DiskEncryptionSet(name, resourceGroup, subscriptionId));
  }
  
  public DiskEncryptionSetNested<A> withNewDiskEncryptionSet() {
    return new DiskEncryptionSetNested(null);
  }
  
  public DiskEncryptionSetNested<A> withNewDiskEncryptionSetLike(DiskEncryptionSet item) {
    return new DiskEncryptionSetNested(item);
  }
  
  public DiskEncryptionSetNested<A> editDiskEncryptionSet() {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(null));
  }
  
  public DiskEncryptionSetNested<A> editOrNewDiskEncryptionSet() {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(new DiskEncryptionSetBuilder().build()));
  }
  
  public DiskEncryptionSetNested<A> editOrNewDiskEncryptionSetLike(DiskEncryptionSet item) {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(item));
  }
  
  public Integer getDiskSizeGB() {
    return this.diskSizeGB;
  }
  
  public A withDiskSizeGB(Integer diskSizeGB) {
    this.diskSizeGB = diskSizeGB;
    return (A) this;
  }
  
  public boolean hasDiskSizeGB() {
    return this.diskSizeGB != null;
  }
  
  public String getDiskType() {
    return this.diskType;
  }
  
  public A withDiskType(String diskType) {
    this.diskType = diskType;
    return (A) this;
  }
  
  public boolean hasDiskType() {
    return this.diskType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OSDiskFluent that = (OSDiskFluent) o;
    if (!java.util.Objects.equals(diskEncryptionSet, that.diskEncryptionSet)) return false;
    if (!java.util.Objects.equals(diskSizeGB, that.diskSizeGB)) return false;
    if (!java.util.Objects.equals(diskType, that.diskType)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(diskEncryptionSet,  diskSizeGB,  diskType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (diskEncryptionSet != null) { sb.append("diskEncryptionSet:"); sb.append(diskEncryptionSet + ","); }
    if (diskSizeGB != null) { sb.append("diskSizeGB:"); sb.append(diskSizeGB + ","); }
    if (diskType != null) { sb.append("diskType:"); sb.append(diskType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class DiskEncryptionSetNested<N> extends DiskEncryptionSetFluent<DiskEncryptionSetNested<N>> implements Nested<N>{
    DiskEncryptionSetNested(DiskEncryptionSet item) {
      this.builder = new DiskEncryptionSetBuilder(this, item);
    }
    DiskEncryptionSetBuilder builder;
    
    public N and() {
      return (N) OSDiskFluent.this.withDiskEncryptionSet(builder.build());
    }
    
    public N endDiskEncryptionSet() {
      return and();
    }
    
  
  }

}

==> openshift-model-hive-6.10.0-sources.jar: io/fabric8/openshift/api/model/hive/azure/v1/OSDiskFluent.java <==
package io.fabric8.openshift.api.model.hive.azure.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OSDiskFluent<A extends OSDiskFluent<A>> extends BaseFluent<A>{
  public OSDiskFluent() {
  }
  
  public OSDiskFluent(OSDisk instance) {
    this.copyInstance(instance);
  }
  private DiskEncryptionSetBuilder diskEncryptionSet;
  private Integer diskSizeGB;
  private String diskType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OSDisk instance) {
    instance = (instance != null ? instance : new OSDisk());
    if (instance != null) {
          this.withDiskEncryptionSet(instance.getDiskEncryptionSet());
          this.withDiskSizeGB(instance.getDiskSizeGB());
          this.withDiskType(instance.getDiskType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public DiskEncryptionSet buildDiskEncryptionSet() {
    return this.diskEncryptionSet != null ? this.diskEncryptionSet.build() : null;
  }
  
  public A withDiskEncryptionSet(DiskEncryptionSet diskEncryptionSet) {
    this._visitables.remove("diskEncryptionSet");
    if (diskEncryptionSet != null) {
        this.diskEncryptionSet = new DiskEncryptionSetBuilder(diskEncryptionSet);
        this._visitables.get("diskEncryptionSet").add(this.diskEncryptionSet);
    } else {
        this.diskEncryptionSet = null;
        this._visitables.get("diskEncryptionSet").remove(this.diskEncryptionSet);
    }
    return (A) this;
  }
  
  public boolean hasDiskEncryptionSet() {
    return this.diskEncryptionSet != null;
  }
  
  public A withNewDiskEncryptionSet(String name,String resourceGroup,String subscriptionId) {
    return (A)withDiskEncryptionSet(new DiskEncryptionSet(name, resourceGroup, subscriptionId));
  }
  
  public DiskEncryptionSetNested<A> withNewDiskEncryptionSet() {
    return new DiskEncryptionSetNested(null);
  }
  
  public DiskEncryptionSetNested<A> withNewDiskEncryptionSetLike(DiskEncryptionSet item) {
    return new DiskEncryptionSetNested(item);
  }
  
  public DiskEncryptionSetNested<A> editDiskEncryptionSet() {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(null));
  }
  
  public DiskEncryptionSetNested<A> editOrNewDiskEncryptionSet() {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(new DiskEncryptionSetBuilder().build()));
  }
  
  public DiskEncryptionSetNested<A> editOrNewDiskEncryptionSetLike(DiskEncryptionSet item) {
    return withNewDiskEncryptionSetLike(java.util.Optional.ofNullable(buildDiskEncryptionSet()).orElse(item));
  }
  
  public Integer getDiskSizeGB() {
    return this.diskSizeGB;
  }
  
  public A withDiskSizeGB(Integer diskSizeGB) {
    this.diskSizeGB = diskSizeGB;
    return (A) this;
  }
  
  public boolean hasDiskSizeGB() {
    return this.diskSizeGB != null;
  }
  
  public String getDiskType() {
    return this.diskType;
  }
  
  public A withDiskType(String diskType) {
    this.diskType = diskType;
    return (A) this;
  }
  
  public boolean hasDiskType() {
    return this.diskType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OSDiskFluent that = (OSDiskFluent) o;
    if (!java.util.Objects.equals(diskEncryptionSet, that.diskEncryptionSet)) return false;
    if (!java.util.Objects.equals(diskSizeGB, that.diskSizeGB)) return false;
    if (!java.util.Objects.equals(diskType, that.diskType)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(diskEncryptionSet,  diskSizeGB,  diskType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (diskEncryptionSet != null) { sb.append("diskEncryptionSet:"); sb.append(diskEncryptionSet + ","); }
    if (diskSizeGB != null) { sb.append("diskSizeGB:"); sb.append(diskSizeGB + ","); }
    if (diskType != null) { sb.append("diskType:"); sb.append(diskType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class DiskEncryptionSetNested<N> extends DiskEncryptionSetFluent<DiskEncryptionSetNested<N>> implements Nested<N>{
    DiskEncryptionSetNested(DiskEncryptionSet item) {
      this.builder = new DiskEncryptionSetBuilder(this, item);
    }
    DiskEncryptionSetBuilder builder;
    
    public N and() {
      return (N) OSDiskFluent.this.withDiskEncryptionSet(builder.build());
    }
    
    public N endDiskEncryptionSet() {
      return and();
    }
    
  
  }

}
